@@ -188,10 +188,17 @@ our %EXPORT_TAGS = (
 
 our @EXPORT_OK = @{$EXPORT_TAGS{all}};
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 # methods
 
+sub new {
+    my $class = shift;
+    my %opts  = @_;
+
+    $class->_new($opts{trace} ? 1 : 0);
+}
+
 sub connect {
     my $self = shift;
     croak "Net::SSH2::connect: not enough parameters" if @_ < 1;
@@ -526,6 +533,10 @@ then create channels on the connection to perform commands.
 
 Create new SSH2 object.
 
+To turn on tracing with a debug build of libssh2 use:
+
+    my $ssh2 = Net::SSH2->new(trace => 1);
+
 =head2 banner ( text )
 
 Set the SSH2 banner text sent to the remote host (prepends required "SSH-2.0-").
